Cando.Permission protocol (cando v0.2.0)

Summary

Types

t()

All the types that implement this protocol.

Functions

Checks if the given subject has permission to perform the specified action.

Types

t()

@type t() :: term()

All the types that implement this protocol.

Functions

can?(subject, action)

@spec can?(any(), any()) :: boolean()

Checks if the given subject has permission to perform the specified action.