Cando.Permission protocol (cando v0.2.0)
View SourceSummary
Functions
Checks if the given subject has permission to perform the specified action.
Types
@type t() :: term()
All the types that implement this protocol.
Checks if the given subject has permission to perform the specified action.
@type t() :: term()
All the types that implement this protocol.